@@ -1,10 +1,10 @@
 import struct
-from .utility import sendRecieveMessage
+from .utility import sendReceiveMessage
 from ..const import code
 
 
 def request_pool_button_press(gateway_socket, circuit_id, circuit_state):
-    response = sendRecieveMessage(
+    response = sendReceiveMessage(
         gateway_socket,
         code.BUTTONPRESS_QUERY,
         struct.pack("<III", 0, circuit_id, circuit_state),
